package com.example.controller;

import cn.hutool.core.date.LocalDateTimeUtil;
import com.example.common.Result;
import com.example.common.enums.OrderStatus;
import com.example.entity.Orders;
import com.example.service.OrdersService;
import com.github.pagehelper.PageInfo;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import java.util.List;

/**
 * Orders订单表接口
 **/
@RestController
@RequestMapping("/orders")
public class OrdersController {

    @Resource
    private OrdersService ordersService;

    /**
     * 创建订单返回生成的订单信息
     * 传参：
     * @param orders
     * @return 订单信息
     */
    @PostMapping("createOrder")
    public Result createOrder(@RequestBody Orders orders){
        return Result.success(ordersService.add(orders));
    }

    /**
     * 商家修改状态为订单已送达
     * 传参 ： id
     * @param orders {id 只需订单id}
     * @return null
     */
    @PostMapping("setOrdersStateArrived")
    public Result setOrdersArrived(@RequestBody Orders orders){
        orders.setOrderState(String.valueOf(OrderStatus.ARRIVED));
        ordersService.updateById(orders);
        return Result.success();
    }

    /**
     * 商家修改状态为订单已完成
     * @param orders {id 只需订单id}
     * @return null
     */
    @PostMapping("ordersFinished")
    public Result setOrdersState(@RequestBody Orders orders){
        orders.setOrderState(String.valueOf(OrderStatus.DONE));
        ordersService.updateById(orders);
        return Result.success();
    }

    /**
     * 删除
     */
    @DeleteMapping("/delete/{id}")
    public Result deleteById(@PathVariable Integer id) {
        ordersService.deleteById(id);
        return Result.success();
    }

    /**
     * 批量删除
     */
    @DeleteMapping("/delete/batch")
    public Result deleteBatch(@RequestBody List<Integer> ids) {
        ordersService.deleteBatch(ids);
        return Result.success();
    }

    /**
     * 修改
     */
    @PutMapping("/update")
    public Result updateById(@RequestBody Orders orders) {
        ordersService.updateById(orders);
        return Result.success();
    }

    /**
     * 根据ID查询
     */
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable Integer id) {
        Orders orders = ordersService.selectById(id);
        return Result.success(orders);
    }

    /**
     * 查询所有
     */
    @GetMapping("/selectAll")
    public Result selectAll(Orders orders) {
        List<Orders> list = ordersService.selectAll(orders);
        return Result.success(list);
    }

    /**
     * 分页查询
     */
    @GetMapping("/selectPage")
    public Result selectPage(Orders orders,
                             @RequestParam(defaultValue = "1") Integer pageNum,
                             @RequestParam(defaultValue = "10") Integer pageSize) {
        PageInfo<Orders> page = ordersService.selectPage(orders, pageNum, pageSize);
        return Result.success(page);
    }

}