package com.example.controller;

import com.example.common.Result;
import com.example.entity.ProductType;
import com.example.service.ProductTypeService;
import com.github.pagehelper.PageInfo;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import java.util.List;

/**
 * ProductType产品类型接口
 **/
@RestController
@RequestMapping("/productType")
public class ProductTypeController {

    @Resource
    private ProductTypeService productTypeService;

    /**
     * 新增
     */
    @PostMapping("/add")
    public Result add(@RequestBody ProductType productType) {
        productTypeService.add(productType);
        return Result.success();
    }

    /**
     * 删除
     */
    @DeleteMapping("/delete/{id}")
    public Result deleteById(@PathVariable Integer id) {
        productTypeService.deleteById(id);
        return Result.success();
    }

    /**
     * 批量删除
     */
    @DeleteMapping("/delete/batch")
    public Result deleteBatch(@RequestBody List<Integer> ids) {
        productTypeService.deleteBatch(ids);
        return Result.success();
    }

    /**
     * 修改
     */
    @PutMapping("/update")
    public Result updateById(@RequestBody ProductType productType) {
        productTypeService.updateById(productType);
        return Result.success();
    }

    /**
     * 根据ID查询
     */
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable Integer id) {
        ProductType productType = productTypeService.selectById(id);
        return Result.success(productType);
    }

    /**
     * 查询所有
     */
    @GetMapping("/selectAll")
    public Result selectAll(ProductType productType) {
        List<ProductType> list = productTypeService.selectAll(productType);
        return Result.success(list);
    }

    /**
     * TODO
     * 根据shopId查询店铺商品
     * @param shopId
     * @return
     */
    @GetMapping("/selectByShopId")
    public Result selectByShopId(Integer shopId){

        return Result.success(productTypeService.selectByShopId(shopId));
    }
    /**
     * 分页查询
     */
    @GetMapping("/selectPage")
    public Result selectPage(ProductType productType,
                             @RequestParam(defaultValue = "1") Integer pageNum,
                             @RequestParam(defaultValue = "10") Integer pageSize) {
        PageInfo<ProductType> page = productTypeService.selectPage(productType, pageNum, pageSize);
        return Result.success(page);
    }

}