package com.example.controller;

import com.example.common.Result;
import com.example.entity.Store;
import com.example.service.StoreService;
import com.github.pagehelper.PageInfo;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import java.util.List;

/**
 * Store店铺接口
 **/
@RestController
@RequestMapping("/store")
public class StoreController {

    @Resource
    private StoreService storeService;

    /**
     * 获取店铺商品类型根据shopId
     * @param shopId
     * @return Result{ProductTypes}
     */
    @GetMapping("/getStoreProductTypesById")
    public Result getStoreProductTypesById(Integer shopId){
        return Result.success(storeService.selectProductsTypesByShopId(shopId));
    }

    /**
     * 根据Id获取店铺商品信息
     * @param storeId
     * @return Result{Product}
     */
    @GetMapping("/getStoreProducts")
    public Result getStoreProductsByStoreId(Integer storeId){
        return Result.success(storeService.selectProducts(storeId));
    }

    /**
     * 新增
     */
    @PostMapping("/add")
    public Result add(@RequestBody Store store) {
        storeService.add(store);
        return Result.success();
    }

    /**
     * 删除
     */
    @DeleteMapping("/delete/{id}")
    public Result deleteById(@PathVariable Integer id) {
        storeService.deleteById(id);
        return Result.success();
    }

    /**
     * 批量删除
     */
    @DeleteMapping("/delete/batch")
    public Result deleteBatch(@RequestBody List<Integer> ids) {
        storeService.deleteBatch(ids);
        return Result.success();
    }

    /**
     * 修改
     */
    @PutMapping("/update")
    public Result updateById(@RequestBody Store store) {
        storeService.updateById(store);
        return Result.success();
    }

    /**
     * 根据ID查询
     */
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable Integer id) {
        Store store = storeService.selectById(id);
        return Result.success(store);
    }

    /**
     * 查询所有
     */
    @GetMapping("/selectAll")
    public Result selectAll(Store store) {
        List<Store> list = storeService.selectAll(store);
        return Result.success(list);
    }

    /**
     * 分页查询
     */
    @GetMapping("/selectPage")
    public Result selectPage(Store store,
                             @RequestParam(defaultValue = "1") Integer pageNum,
                             @RequestParam(defaultValue = "10") Integer pageSize) {
        PageInfo<Store> page = storeService.selectPage(store, pageNum, pageSize);
        return Result.success(page);
    }

}