package com.example.typeHandler;

import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

/**
 * 功能：
 * 数据库定义了类型 Array<Integer> 需要配置typeHandler
 * @author 熊浩毅
 * @time 2024-02-10 20:07
 * @Description
 */
public class ArrayIntegerTypeHadnler extends BaseTypeHandler<Integer[]> {
    private static Logger log = LoggerFactory.getLogger(ArrayIntegerTypeHadnler.class);
    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, Integer[] params, JdbcType jdbcType) throws SQLException {
        StringBuffer sb = new StringBuffer();
        sb.append("[");
        for(Integer param : params){
            sb.append(param+",");
        }
        sb.deleteCharAt(sb.length()-1);
        sb.append("]");
        log.warn(sb.toString());
        ps.setString(i,sb.toString());
    }

    @Override
    public Integer[] getNullableResult(ResultSet resultSet, String columnName) throws SQLException {
        return convertToArray(resultSet.getString(columnName));
    }

    @Override
    public Integer[] getNullableResult(ResultSet resultSet, int index) throws SQLException {
        return convertToArray(resultSet.getString(index));
    }

    @Override
    public Integer[] getNullableResult(CallableStatement callableStatement, int columnIndex) throws SQLException {
        return convertToArray(callableStatement.getString(columnIndex));
    }

    /**
     * 转换回数组
     * @param stringValue
     * @return
     */
    private Integer[] convertToArray(String stringValue) {
        if (stringValue == null || stringValue.isEmpty()) {
            return null;
        }
        // 假设数据库中的格式是类似 "[1,2,3]" 的字符串，需要去除首尾的方括号，然后按逗号分割
        stringValue = stringValue.substring(1, stringValue.length() - 1);
        String[] stringArray = stringValue.split(",");
        Integer[] intArray = new Integer[stringArray.length];
        for (int i = 0; i < stringArray.length; i++) {
            intArray[i] = Integer.parseInt(stringArray[i].trim());
        }
        return intArray;
    }

}

