package com.example.typeHandler;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

/**
 * 功能： List <String>
 *
 * @author 熊浩毅
 * @time 2024-02-17 15:33
 * @Description
 */
public class ArrayStringTypeHandler extends BaseTypeHandler<List<String>> {
    private static final ObjectMapper objectMapper =new ObjectMapper();
    @Override
    public void setNonNullParameter(PreparedStatement preparedStatement, int i, List<String> stringList, JdbcType jdbcType) throws SQLException {
        preparedStatement.setString(i, toJson(stringList));
    }

    @Override
    public List<String> getNullableResult(ResultSet resultSet, String s) throws SQLException {
        return fromJson(resultSet.getString(s));
    }

    @Override
    public List<String> getNullableResult(ResultSet resultSet, int columnIndex) throws SQLException {
        return fromJson(resultSet.getString(columnIndex));
    }

    @Override
    public List<String> getNullableResult(CallableStatement callableStatement, int columnIndex) throws SQLException {
        return fromJson(callableStatement.getString(columnIndex));
    }

    private String toJson(List<String> object) {
        try {
            return objectMapper.writeValueAsString(object);
        } catch (Exception e) {
            throw new RuntimeException("Error converting object to JSON string", e);
        }
    }

    private List<String> fromJson(String json) {
        try {
            return objectMapper.readValue(json, new TypeReference<List<String>>() {});
        } catch (Exception e) {
            throw new RuntimeException("Error converting JSON string to object", e);
        }
    }
}
